==> share_apps-0.0.4.tar.gz: lib/utils/string_utils.dart <==
class StringUtils {
  // Images
  static const String BASE_IMAGE = 'assets/images/';
  static const String IC_LOGO = BASE_IMAGE + 'ic_logo.png';

  // Api Constants
  static String _TOKEN_VALUE = '';

  static String getToken() => '8609140475'; // _TOKEN_VALUE;

  static void setToken(String value) {
    _TOKEN_VALUE = value;
  }

  static const String APP_ID_PARAMETER = 'Auth-id';
  static const String APP_SECRET_PARAMETER = 'Auth-secret';
  static const String CONTECT_TYPE_PARAMETER = 'Content-type';
  static const String ACCEPT_PARAMETER = 'Accept';
  static const String APPLICATION_JSON_VALUE = 'application/json';
  static String APP_ID = '';
  static String APP_SECRET = '';
  static const String API_BASE_URL = 'https://shareapps.net/api/app/';
  static const String API_REGISTRATION = API_BASE_URL + 'register';
  static const String API_TEST_EMAIL = API_BASE_URL + 'test-email';
  static const String API_TEST_SMS = API_BASE_URL + 'test-sms';
  static const String LEARN_MORE_URL = 'https://shareapps.net/how-it-works';
  static const String INVITE_CONTACT = API_BASE_URL + 'transfer';
  static const String BEGIN_TRANSFER = API_BASE_URL + 'begin-transfer';
  static const String END_TRANSFER = API_BASE_URL + 'close-transfer';
  static const String COMPLETE_INVITATION_LEARN_MORE_URL =
      'https://shareapps.net/how-to-promote-mobile-apps';

  // parameters
  static const String CONTACTS = 'contacts';
  static const String TRANSACTION_ID = 'transaction_id';
  static const String TRANSFER_ID = 'transfer_id';
  static const String TOKEN = 'token';
  static const String OS = 'os';
  static const String OS_VALUE = '1';
  static const String DEVICE_ID = 'device_id';
  static const String COUNTRY_ID = 'country_id';
  static const String PHONE_NUMBER_PARAM = 'phone_number';
  static const String TEMPLATE_ID = 'template_id';
  static const String TEMPLATE_ID_VALUE = '2';
  static const String EMAIL_PARAM = 'email';
  static const String MESSAGE = 'message';
  static const String STATUS = 'status';
  static const String SUCCESS = 'success';

  // Strings
  static const String APP_NAME = 'Share Apps';
  static const String INVITE_FRIENDS = 'Invite Friends';
  static const String FIRST_NAME = 'First Name';
  static const String LAST_NAME = 'Last Name';
  static const String EMAIL = 'Email Address';
  static const String COUNTRY = 'Country';
  static const String PHONE_NUMBER = 'Phone Number';
  static const String LANGUAGE = 'Language';
  static const String ENTER = 'Enter';
  static const String SELECT = 'Select';
  static const String PROCEED = 'Proceed';
  static const String EXIT = 'Exit';
  static const String CHECK_NETWORK = 'Check Network';
  static const String THANK_YOU = 'Thank You!';
  static const String INVITATION_COMPLETE = 'invitation complete';
  static const String REGISTRATION_WAIT_MESSAGE =
      'Please wait.\nApp registration in progress.';
  static const String INVITE_CONTACT_MESSAGE =
      'Please wait. Inviting friends.\nA lots of contacts. This will take a while';
  static const String EMAIL_FRIENDS = 'Email Friends';
  static const String PHONE_BOOK_FRIENDS = 'Phonebook Friends';
  static const String THANKS_FOR_INSTALLING =
      'Thanks for installing this application.';
  static const String WELCOME_SHAREAPP = ' Welcome to ShareApps';
  static const String INVITE_FRIENDS_ = 'Invite a Friend?';
  static const String SAMPLE_SMS_INVITE = 'Sample sms invite';
  static const String SAMPLE_EMAIL_INVITE = 'Sample email invite';
  static const String TERMS_AND_CONDITION = 'Terms and conditions apply.';
  static const String LEARN_MORE = 'Learn more';
  static const String CANCEL = 'Cancel';
  static const String SELECT_ALL = 'Select All';
  static const String PROCEED_ = 'Proceed>';
  static const String SEARCH_NUMBER_HINT = 'Type to Search Number';
  static const String CHECK_EMAIL_VALIDATION = 'Enter valid EmailAddress';
  static const String CONTACT_SELECTION_TITLE = 'Select Contact';
  static const String USER_DATA = 'user_data';

  static Map<String, String> GetApiHeaders() {
    return {
      APP_ID_PARAMETER: StringUtils.APP_ID,
      APP_SECRET_PARAMETER: StringUtils.APP_SECRET,
      CONTECT_TYPE_PARAMETER: APPLICATION_JSON_VALUE,
      ACCEPT_PARAMETER: APPLICATION_JSON_VALUE,
    };
  }
}

==> share_apps-0.0.5.tar.gz: lib/utils/string_utils.dart <==
class StringUtils {
  // Images
  static const String BASE_IMAGE = 'assets/images/';
  static const String IC_LOGO = BASE_IMAGE + 'ic_logo.png';

  // Api Constants
  static String _TOKEN_VALUE = '';

  static String getToken() => _TOKEN_VALUE;

  static void setToken(String value) {
    _TOKEN_VALUE = value;
  }

  static const String APP_ID_PARAMETER = 'Auth-id';
  static const String APP_SECRET_PARAMETER = 'Auth-secret';
  static const String CONTECT_TYPE_PARAMETER = 'Content-type';
  static const String ACCEPT_PARAMETER = 'Accept';
  static const String APPLICATION_JSON_VALUE = 'application/json';
  static String APP_ID = '';
  static String APP_SECRET = '';
  static const String API_BASE_URL = 'https://shareapps.net/api/app/';
  static const String API_REGISTRATION = API_BASE_URL + 'register';
  static const String API_TEST_EMAIL = API_BASE_URL + 'test-email';
  static const String API_TEST_SMS = API_BASE_URL + 'test-sms';
  static const String LEARN_MORE_URL = 'https://shareapps.net/how-it-works';
  static const String INVITE_CONTACT = API_BASE_URL + 'transfer';
  static const String BEGIN_TRANSFER = API_BASE_URL + 'begin-transfer';
  static const String END_TRANSFER = API_BASE_URL + 'close-transfer';
  static const String COMPLETE_INVITATION_LEARN_MORE_URL =
      'https://shareapps.net/how-to-promote-mobile-apps';

  // parameters
  static const String CONTACTS = 'contacts';
  static const String TRANSACTION_ID = 'transaction_id';
  static const String TRANSFER_ID = 'transfer_id';
  static const String TOKEN = 'token';
  static const String OS = 'os';
  static const String OS_VALUE = '1';
  static const String DEVICE_ID = 'device_id';
  static const String COUNTRY_ID = 'country_id';
  static const String PHONE_NUMBER_PARAM = 'phone_number';
  static const String TEMPLATE_ID = 'template_id';
  static const String TEMPLATE_ID_VALUE = '2';
  static const String EMAIL_PARAM = 'email';
  static const String MESSAGE = 'message';
  static const String STATUS = 'status';
  static const String SUCCESS = 'success';

  // Strings
  static const String APP_NAME = 'Share Apps';
  static const String INVITE_FRIENDS = 'Invite Friends';
  static const String FIRST_NAME = 'First Name';
  static const String LAST_NAME = 'Last Name';
  static const String EMAIL = 'Email Address';
  static const String COUNTRY = 'Country';
  static const String PHONE_NUMBER = 'Phone Number';
  static const String LANGUAGE = 'Language';
  static const String ENTER = 'Enter';
  static const String SELECT = 'Select';
  static const String PROCEED = 'Proceed';
  static const String EXIT = 'Exit';
  static const String CHECK_NETWORK = 'Check Network';
  static const String THANK_YOU = 'Thank You!';
  static const String INVITATION_COMPLETE = 'invitation complete';
  static const String REGISTRATION_WAIT_MESSAGE =
      'Please wait.\nApp registration in progress.';
  static const String INVITE_CONTACT_MESSAGE =
      'Please wait. Inviting friends.\nA lots of contacts. This will take a while';
  static const String EMAIL_FRIENDS = 'Email Friends';
  static const String PHONE_BOOK_FRIENDS = 'Phonebook Friends';
  static const String THANKS_FOR_INSTALLING =
      'Thanks for installing this application.';
  static const String WELCOME_SHAREAPP = ' Welcome to ShareApps';
  static const String INVITE_FRIENDS_ = 'Invite a Friend?';
  static const String SAMPLE_SMS_INVITE = 'Sample sms invite';
  static const String SAMPLE_EMAIL_INVITE = 'Sample email invite';
  static const String TERMS_AND_CONDITION = 'Terms and conditions apply.';
  static const String LEARN_MORE = 'Learn more';
  static const String CANCEL = 'Cancel';
  static const String SELECT_ALL = 'Select All';
  static const String PROCEED_ = 'Proceed>';
  static const String SEARCH_NUMBER_HINT = 'Type to Search Number';
  static const String CHECK_EMAIL_VALIDATION = 'Enter valid EmailAddress';
  static const String CONTACT_SELECTION_TITLE = 'Select Contact';
  static const String USER_DATA = 'user_data';

  static Map<String, String> GetApiHeaders() {
    return {
      APP_ID_PARAMETER: StringUtils.APP_ID,
      APP_SECRET_PARAMETER: StringUtils.APP_SECRET,
      CONTECT_TYPE_PARAMETER: APPLICATION_JSON_VALUE,
      ACCEPT_PARAMETER: APPLICATION_JSON_VALUE,
    };
  }
}
